@@ -5,7 +5,7 @@ import argparse
 global distro 
 distro = ["apt","yay", "paru", "pacman", "dnf"]
 global found # you need your path setup to .local/bin in shell to run this script to get the distro pakacge manager
-found = subprocess.getoutput("/home/ahmed/.local/lib/python3.9/site-packages/LibreGaming/./getPackageManager.sh")
+found = subprocess.getoutput("~/.local/lib/python3.9/site-packages/LibreGaming/./getPackageManager.sh")
 #print (found)
 
 def installPkgs():
